"""命令模块初始化"""

from . import init, add, ls, get, delete, groups, set_default, search, stats, tags

__all__ = ["init", "add", "ls", "get", "delete", "groups", "set_default", "search", "stats", "tags"]
